@@ -63,8 +63,8 @@ new ApiGatewayToSqs(this, "ApiGatewayToSqsPattern", new ApiGatewayToSqsProps.Bui
 
 | **Name**     | **Type**        | **Description** |
 |:-------------|:----------------|-----------------|
-|apiGatewayProps?|[`api.RestApiProps`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-apigateway.RestApiProps.html)|Optional user-provided props to override the default props for the API Gateway.|
-|queueProps?|[`sqs.QueueProps`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-sqs.QueueProps.html)|Optional user-provided props to override the default props for the queue.|
+|apiGatewayProps?|[`api.RestApiProps`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_apigateway.RestApiProps.html)|Optional user-provided props to override the default props for the API Gateway.|
+|queueProps?|[`sqs.QueueProps`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_sqs.QueueProps.html)|Optional user-provided props to override the default props for the queue.|
 |deployDeadLetterQueue?|`boolean`|Whether to deploy a secondary queue to be used as a dead letter queue. Defaults to `true`.|
 |maxReceiveCount|`number`|The number of times a message can be unsuccessfully dequeued before being moved to the dead-letter queue.|
 |allowCreateOperation?|`boolean`|Whether to deploy an API Gateway Method for Create operations on the queue (i.e. sqs:SendMessage).|
@@ -73,18 +73,21 @@ new ApiGatewayToSqs(this, "ApiGatewayToSqsPattern", new ApiGatewayToSqsProps.Bui
 |readRequestTemplate?|`string`|Override the default API Gateway Request template for Read method, if allowReadOperation set to true.|
 |allowDeleteOperation?|`boolean`|Whether to deploy an API Gateway Method for Delete operations on the queue (i.e. sqs:DeleteMessage).|
 |deleteRequestTemplate?|`string`|Override the default API Gateway Request template for Delete method, if allowDeleteOperation set to true.|
-|logGroupProps?|[`logs.LogGroupProps`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-logs.LogGroupProps.html)|User provided props to override the default props for for the CloudWatchLogs LogGroup.|
+|logGroupProps?|[`logs.LogGroupProps`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_logs.LogGroupProps.html)|User provided props to override the default props for for the CloudWatchLogs LogGroup.|
+|enableEncryptionWithCustomerManagedKey?|`boolean`|If no key is provided, this flag determines whether the queue is encrypted with a new CMK or an AWS managed key. This flag is ignored if any of the following are defined: queueProps.encryptionMasterKey, encryptionKey or encryptionKeyProps.|
+|encryptionKey?|[`kms.Key`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_kms.Key.html)|An optional, imported encryption key to encrypt the SQS Queue with.|
+|encryptionKeyProps?|[`kms.KeyProps`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_kms.Key.html#construct-props)|Optional user provided properties to override the default properties for the KMS encryption key used to encrypt the SQS queue with.|
 
 ## Pattern Properties
 
 | **Name**     | **Type**        | **Description** |
 |:-------------|:----------------|-----------------|
-|apiGateway|[`api.RestApi`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-apigateway.RestApi.html)|Returns an instance of the API Gateway REST API created by the pattern.|
-|apiGatewayRole|[`iam.Role`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-iam.Role.html)|Returns an instance of the iam.Role created by the construct for API Gateway.|
-|apiGatewayCloudWatchRole?|[`iam.Role`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-iam.Role.html)|Returns an instance of the iam.Role created by the construct for API Gateway for CloudWatch access.|
-|apiGatewayLogGroup|[`logs.LogGroup`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-logs.LogGroup.html)|Returns an instance of the LogGroup created by the construct for API Gateway access logging to CloudWatch.|
-|sqsQueue|[`sqs.Queue`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-sqs.Queue.html)|Returns an instance of the SQS queue created by the pattern.|
-|deadLetterQueue?|[`sqs.DeadLetterQueue`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-sqs.DeadLetterQueue.html)|Returns an instance of the DeadLetterQueue created by the pattern.|
+|apiGateway|[`api.RestApi`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_apigateway.RestApi.html)|Returns an instance of the API Gateway REST API created by the pattern.|
+|apiGatewayRole|[`iam.Role`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_iam.Role.html)|Returns an instance of the iam.Role created by the construct for API Gateway.|
+|apiGatewayCloudWatchRole?|[`iam.Role`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_iam.Role.html)|Returns an instance of the iam.Role created by the construct for API Gateway for CloudWatch access.|
+|apiGatewayLogGroup|[`logs.LogGroup`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_logs.LogGroup.html)|Returns an instance of the LogGroup created by the construct for API Gateway access logging to CloudWatch.|
+|sqsQueue|[`sqs.Queue`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_sqs.Queue.html)|Returns an instance of the SQS queue created by the pattern.|
+|deadLetterQueue?|[`sqs.DeadLetterQueue`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_sqs.DeadLetterQueue.html)|Returns an instance of the DeadLetterQueue created by the pattern.|
 
 ## Sample API Usage
 
@@ -137,6 +140,7 @@ from ._jsii import *
 
 import aws_cdk.aws_apigateway
 import aws_cdk.aws_iam
+import aws_cdk.aws_kms
 import aws_cdk.aws_logs
 import aws_cdk.aws_sqs
 import constructs
@@ -164,6 +168,9 @@ class ApiGatewayToSqs(
         dead_letter_queue_props: typing.Optional[typing.Union[aws_cdk.aws_sqs.QueueProps, typing.Dict[str, typing.Any]]] = None,
         delete_request_template: typing.Optional[builtins.str] = None,
         deploy_dead_letter_queue: typing.Optional[builtins.bool] = None,
+        enable_encryption_with_customer_managed_key: typing.Optional[builtins.bool] = None,
+        encryption_key: typing.Optional[aws_cdk.aws_kms.Key] = None,
+        encryption_key_props: typing.Optional[typing.Union[aws_cdk.aws_kms.KeyProps, typing.Dict[str, typing.Any]]] = None,
         existing_queue_obj: typing.Optional[aws_cdk.aws_sqs.Queue] = None,
         log_group_props: typing.Optional[typing.Union[aws_cdk.aws_logs.LogGroupProps, typing.Dict[str, typing.Any]]] = None,
         max_receive_count: typing.Optional[jsii.Number] = None,
@@ -181,6 +188,9 @@ class ApiGatewayToSqs(
         :param dead_letter_queue_props: Optional user provided properties for the dead letter queue. Default: - Default props are used
         :param delete_request_template: API Gateway Request template for Delete method, if allowDeleteOperation set to true. Default: - "Action=DeleteMessage&ReceiptHandle=$util.urlEncode($input.params('receiptHandle'))"
         :param deploy_dead_letter_queue: Whether to deploy a secondary queue to be used as a dead letter queue. Default: - required field.
+        :param enable_encryption_with_customer_managed_key: If no key is provided, this flag determines whether the queue is encrypted with a new CMK or an AWS managed key. This flag is ignored if any of the following are defined: queueProps.encryptionMasterKey, encryptionKey or encryptionKeyProps. Default: - False if queueProps.encryptionMasterKey, encryptionKey, and encryptionKeyProps are all undefined.
+        :param encryption_key: An optional, imported encryption key to encrypt the SQS Queue with. Default: - None
+        :param encryption_key_props: Optional user provided properties to override the default properties for the KMS encryption key used to encrypt the SQS queue with. Default: - None
         :param existing_queue_obj: Existing instance of SQS queue object, providing both this and queueProps will cause an error. Default: - None
         :param log_group_props: User provided props to override the default props for the CloudWatchLogs LogGroup. Default: - Default props are used
         :param max_receive_count: The number of times a message can be unsuccessfully dequeued before being moved to the dead-letter queue. Default: - required only if deployDeadLetterQueue = true.
@@ -192,7 +202,29 @@ class ApiGatewayToSqs(
         :summary: Constructs a new instance of the ApiGatewayToSqs class.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(ApiGatewayToSqs.__init__)
+            def stub(
+                scope: constructs.Construct,
+                id: builtins.str,
+                *,
+                allow_create_operation: typing.Optional[builtins.bool] = None,
+                allow_delete_operation: typing.Optional[builtins.bool] = None,
+                allow_read_operation: typing.Optional[builtins.bool] = None,
+                api_gateway_props: typing.Any = None,
+                create_request_template: typing.Optional[builtins.str] = None,
+                dead_letter_queue_props: typing.Optional[typing.Union[aws_cdk.aws_sqs.QueueProps, typing.Dict[str, typing.Any]]] = None,
+                delete_request_template: typing.Optional[builtins.str] = None,
+                deploy_dead_letter_queue: typing.Optional[builtins.bool] = None,
+                enable_encryption_with_customer_managed_key: typing.Optional[builtins.bool] = None,
+                encryption_key: typing.Optional[aws_cdk.aws_kms.Key] = None,
+                encryption_key_props: typing.Optional[typing.Union[aws_cdk.aws_kms.KeyProps, typing.Dict[str, typing.Any]]] = None,
+                existing_queue_obj: typing.Optional[aws_cdk.aws_sqs.Queue] = None,
+                log_group_props: typing.Optional[typing.Union[aws_cdk.aws_logs.LogGroupProps, typing.Dict[str, typing.Any]]] = None,
+                max_receive_count: typing.Optional[jsii.Number] = None,
+                queue_props: typing.Optional[typing.Union[aws_cdk.aws_sqs.QueueProps, typing.Dict[str, typing.Any]]] = None,
+                read_request_template: typing.Optional[builtins.str] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = ApiGatewayToSqsProps(
@@ -204,6 +236,9 @@ class ApiGatewayToSqs(
             dead_letter_queue_props=dead_letter_queue_props,
             delete_request_template=delete_request_template,
             deploy_dead_letter_queue=deploy_dead_letter_queue,
+            enable_encryption_with_customer_managed_key=enable_encryption_with_customer_managed_key,
+            encryption_key=encryption_key,
+            encryption_key_props=encryption_key_props,
             existing_queue_obj=existing_queue_obj,
             log_group_props=log_group_props,
             max_receive_count=max_receive_count,
@@ -256,6 +291,9 @@ class ApiGatewayToSqs(
         "dead_letter_queue_props": "deadLetterQueueProps",
         "delete_request_template": "deleteRequestTemplate",
         "deploy_dead_letter_queue": "deployDeadLetterQueue",
+        "enable_encryption_with_customer_managed_key": "enableEncryptionWithCustomerManagedKey",
+        "encryption_key": "encryptionKey",
+        "encryption_key_props": "encryptionKeyProps",
         "existing_queue_obj": "existingQueueObj",
         "log_group_props": "logGroupProps",
         "max_receive_count": "maxReceiveCount",
@@ -275,6 +313,9 @@ class ApiGatewayToSqsProps:
         dead_letter_queue_props: typing.Optional[typing.Union[aws_cdk.aws_sqs.QueueProps, typing.Dict[str, typing.Any]]] = None,
         delete_request_template: typing.Optional[builtins.str] = None,
         deploy_dead_letter_queue: typing.Optional[builtins.bool] = None,
+        enable_encryption_with_customer_managed_key: typing.Optional[builtins.bool] = None,
+        encryption_key: typing.Optional[aws_cdk.aws_kms.Key] = None,
+        encryption_key_props: typing.Optional[typing.Union[aws_cdk.aws_kms.KeyProps, typing.Dict[str, typing.Any]]] = None,
         existing_queue_obj: typing.Optional[aws_cdk.aws_sqs.Queue] = None,
         log_group_props: typing.Optional[typing.Union[aws_cdk.aws_logs.LogGroupProps, typing.Dict[str, typing.Any]]] = None,
         max_receive_count: typing.Optional[jsii.Number] = None,
@@ -290,6 +331,9 @@ class ApiGatewayToSqsProps:
         :param dead_letter_queue_props: Optional user provided properties for the dead letter queue. Default: - Default props are used
         :param delete_request_template: API Gateway Request template for Delete method, if allowDeleteOperation set to true. Default: - "Action=DeleteMessage&ReceiptHandle=$util.urlEncode($input.params('receiptHandle'))"
         :param deploy_dead_letter_queue: Whether to deploy a secondary queue to be used as a dead letter queue. Default: - required field.
+        :param enable_encryption_with_customer_managed_key: If no key is provided, this flag determines whether the queue is encrypted with a new CMK or an AWS managed key. This flag is ignored if any of the following are defined: queueProps.encryptionMasterKey, encryptionKey or encryptionKeyProps. Default: - False if queueProps.encryptionMasterKey, encryptionKey, and encryptionKeyProps are all undefined.
+        :param encryption_key: An optional, imported encryption key to encrypt the SQS Queue with. Default: - None
+        :param encryption_key_props: Optional user provided properties to override the default properties for the KMS encryption key used to encrypt the SQS queue with. Default: - None
         :param existing_queue_obj: Existing instance of SQS queue object, providing both this and queueProps will cause an error. Default: - None
         :param log_group_props: User provided props to override the default props for the CloudWatchLogs LogGroup. Default: - Default props are used
         :param max_receive_count: The number of times a message can be unsuccessfully dequeued before being moved to the dead-letter queue. Default: - required only if deployDeadLetterQueue = true.
@@ -300,12 +344,34 @@ class ApiGatewayToSqsProps:
         '''
         if isinstance(dead_letter_queue_props, dict):
             dead_letter_queue_props = aws_cdk.aws_sqs.QueueProps(**dead_letter_queue_props)
+        if isinstance(encryption_key_props, dict):
+            encryption_key_props = aws_cdk.aws_kms.KeyProps(**encryption_key_props)
         if isinstance(log_group_props, dict):
             log_group_props = aws_cdk.aws_logs.LogGroupProps(**log_group_props)
         if isinstance(queue_props, dict):
             queue_props = aws_cdk.aws_sqs.QueueProps(**queue_props)
         if __debug__:
-            type_hints = typing.get_type_hints(ApiGatewayToSqsProps.__init__)
+            def stub(
+                *,
+                allow_create_operation: typing.Optional[builtins.bool] = None,
+                allow_delete_operation: typing.Optional[builtins.bool] = None,
+                allow_read_operation: typing.Optional[builtins.bool] = None,
+                api_gateway_props: typing.Any = None,
+                create_request_template: typing.Optional[builtins.str] = None,
+                dead_letter_queue_props: typing.Optional[typing.Union[aws_cdk.aws_sqs.QueueProps, typing.Dict[str, typing.Any]]] = None,
+                delete_request_template: typing.Optional[builtins.str] = None,
+                deploy_dead_letter_queue: typing.Optional[builtins.bool] = None,
+                enable_encryption_with_customer_managed_key: typing.Optional[builtins.bool] = None,
+                encryption_key: typing.Optional[aws_cdk.aws_kms.Key] = None,
+                encryption_key_props: typing.Optional[typing.Union[aws_cdk.aws_kms.KeyProps, typing.Dict[str, typing.Any]]] = None,
+                existing_queue_obj: typing.Optional[aws_cdk.aws_sqs.Queue] = None,
+                log_group_props: typing.Optional[typing.Union[aws_cdk.aws_logs.LogGroupProps, typing.Dict[str, typing.Any]]] = None,
+                max_receive_count: typing.Optional[jsii.Number] = None,
+                queue_props: typing.Optional[typing.Union[aws_cdk.aws_sqs.QueueProps, typing.Dict[str, typing.Any]]] = None,
+                read_request_template: typing.Optional[builtins.str] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument allow_create_operation", value=allow_create_operation, expected_type=type_hints["allow_create_operation"])
             check_type(argname="argument allow_delete_operation", value=allow_delete_operation, expected_type=type_hints["allow_delete_operation"])
             check_type(argname="argument allow_read_operation", value=allow_read_operation, expected_type=type_hints["allow_read_operation"])
@@ -314,6 +380,9 @@ class ApiGatewayToSqsProps:
             check_type(argname="argument dead_letter_queue_props", value=dead_letter_queue_props, expected_type=type_hints["dead_letter_queue_props"])
             check_type(argname="argument delete_request_template", value=delete_request_template, expected_type=type_hints["delete_request_template"])
             check_type(argname="argument deploy_dead_letter_queue", value=deploy_dead_letter_queue, expected_type=type_hints["deploy_dead_letter_queue"])
+            check_type(argname="argument enable_encryption_with_customer_managed_key", value=enable_encryption_with_customer_managed_key, expected_type=type_hints["enable_encryption_with_customer_managed_key"])
+            check_type(argname="argument encryption_key", value=encryption_key, expected_type=type_hints["encryption_key"])
+            check_type(argname="argument encryption_key_props", value=encryption_key_props, expected_type=type_hints["encryption_key_props"])
             check_type(argname="argument existing_queue_obj", value=existing_queue_obj, expected_type=type_hints["existing_queue_obj"])
             check_type(argname="argument log_group_props", value=log_group_props, expected_type=type_hints["log_group_props"])
             check_type(argname="argument max_receive_count", value=max_receive_count, expected_type=type_hints["max_receive_count"])
@@ -336,6 +405,12 @@ class ApiGatewayToSqsProps:
             self._values["delete_request_template"] = delete_request_template
         if deploy_dead_letter_queue is not None:
             self._values["deploy_dead_letter_queue"] = deploy_dead_letter_queue
+        if enable_encryption_with_customer_managed_key is not None:
+            self._values["enable_encryption_with_customer_managed_key"] = enable_encryption_with_customer_managed_key
+        if encryption_key is not None:
+            self._values["encryption_key"] = encryption_key
+        if encryption_key_props is not None:
+            self._values["encryption_key_props"] = encryption_key_props
         if existing_queue_obj is not None:
             self._values["existing_queue_obj"] = existing_queue_obj
         if log_group_props is not None:
@@ -419,6 +494,37 @@ class ApiGatewayToSqsProps:
         result = self._values.get("deploy_dead_letter_queue")
         return typing.cast(typing.Optional[builtins.bool], result)
 
+    @builtins.property
+    def enable_encryption_with_customer_managed_key(
+        self,
+    ) -> typing.Optional[builtins.bool]:
+        '''If no key is provided, this flag determines whether the queue is encrypted with a new CMK or an AWS managed key.
+
+        This flag is ignored if any of the following are defined: queueProps.encryptionMasterKey, encryptionKey or encryptionKeyProps.
+
+        :default: - False if queueProps.encryptionMasterKey, encryptionKey, and encryptionKeyProps are all undefined.
+        '''
+        result = self._values.get("enable_encryption_with_customer_managed_key")
+        return typing.cast(typing.Optional[builtins.bool], result)
+
+    @builtins.property
+    def encryption_key(self) -> typing.Optional[aws_cdk.aws_kms.Key]:
+        '''An optional, imported encryption key to encrypt the SQS Queue with.
+
+        :default: - None
+        '''
+        result = self._values.get("encryption_key")
+        return typing.cast(typing.Optional[aws_cdk.aws_kms.Key], result)
+
+    @builtins.property
+    def encryption_key_props(self) -> typing.Optional[aws_cdk.aws_kms.KeyProps]:
+        '''Optional user provided properties to override the default properties for the KMS encryption key used to encrypt the SQS queue with.
+
+        :default: - None
+        '''
+        result = self._values.get("encryption_key_props")
+        return typing.cast(typing.Optional[aws_cdk.aws_kms.KeyProps], result)
+
     @builtins.property
     def existing_queue_obj(self) -> typing.Optional[aws_cdk.aws_sqs.Queue]:
         '''Existing instance of SQS queue object, providing both this  and queueProps will cause an error.
